{
  "type": "record",
  "Aspect": {
    "name": "assertionAssignmentRuleKey",
    "keyForEntity": "assertionAssignmentRule",
    "entityCategory": "core",
    "entityAspects": [
      "assertionAssignmentRuleInfo",
      "ownership",
      "status"
    ],
    "entityDoc": "A rule that automatically assigns assertions and subscriptions to entities matching a filter."
  },
  "name": "AssertionAssignmentRuleKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "fields": [
    {
      "type": "string",
      "name": "id",
      "doc": "Unique id for the assertion assignment rule."
    }
  ],
  "doc": "Key for an Assertion Assignment Rule"
}