# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from ......schema_classes import AssertionAssignmentRuleFilterClass
from ......schema_classes import AssertionAssignmentRuleInfoClass
from ......schema_classes import AssertionAssignmentRuleModeClass
from ......schema_classes import FreshnessAssertionAssignmentRuleConfigClass
from ......schema_classes import SubscriberAssignmentConfigClass
from ......schema_classes import SubscriptionAssignmentRuleConfigClass
from ......schema_classes import VolumeAssertionAssignmentRuleConfigClass


AssertionAssignmentRuleFilter = AssertionAssignmentRuleFilterClass
AssertionAssignmentRuleInfo = AssertionAssignmentRuleInfoClass
AssertionAssignmentRuleMode = AssertionAssignmentRuleModeClass
FreshnessAssertionAssignmentRuleConfig = FreshnessAssertionAssignmentRuleConfigClass
SubscriberAssignmentConfig = SubscriberAssignmentConfigClass
SubscriptionAssignmentRuleConfig = SubscriptionAssignmentRuleConfigClass
VolumeAssertionAssignmentRuleConfig = VolumeAssertionAssignmentRuleConfigClass

# fmt: on
