# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import IncidentActivityChangeClass
from .....schema_classes import IncidentActivityChangeTypeClass
from .....schema_classes import IncidentActivityEventClass
from .....schema_classes import IncidentAssigneeClass
from .....schema_classes import IncidentExternalLinkClass
from .....schema_classes import IncidentExternalLinksClass
from .....schema_classes import IncidentInfoClass
from .....schema_classes import IncidentNoteClass
from .....schema_classes import IncidentNoteSourceClass
from .....schema_classes import IncidentNoteSourceTypeClass
from .....schema_classes import IncidentNotesClass
from .....schema_classes import IncidentNotificationDetailsClass
from .....schema_classes import IncidentSourceClass
from .....schema_classes import IncidentSourceTypeClass
from .....schema_classes import IncidentStageClass
from .....schema_classes import IncidentStateClass
from .....schema_classes import IncidentStatusClass
from .....schema_classes import IncidentTypeClass
from .....schema_classes import SlackIncidentDetailsClass
from .....schema_classes import SlackMessageDetailsClass


IncidentActivityChange = IncidentActivityChangeClass
IncidentActivityChangeType = IncidentActivityChangeTypeClass
IncidentActivityEvent = IncidentActivityEventClass
IncidentAssignee = IncidentAssigneeClass
IncidentExternalLink = IncidentExternalLinkClass
IncidentExternalLinks = IncidentExternalLinksClass
IncidentInfo = IncidentInfoClass
IncidentNote = IncidentNoteClass
IncidentNoteSource = IncidentNoteSourceClass
IncidentNoteSourceType = IncidentNoteSourceTypeClass
IncidentNotes = IncidentNotesClass
IncidentNotificationDetails = IncidentNotificationDetailsClass
IncidentSource = IncidentSourceClass
IncidentSourceType = IncidentSourceTypeClass
IncidentStage = IncidentStageClass
IncidentState = IncidentStateClass
IncidentStatus = IncidentStatusClass
IncidentType = IncidentTypeClass
SlackIncidentDetails = SlackIncidentDetailsClass
SlackMessageDetails = SlackMessageDetailsClass

# fmt: on
