{
  "type": "record",
  "Aspect": {
    "name": "assertionRunSummary"
  },
  "name": "AssertionRunSummary",
  "namespace": "com.linkedin.pegasus2avro.assertion",
  "fields": [
    {
      "Searchable": {
        "fieldName": "lastFailedAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastFailedAtMillis",
      "default": null,
      "doc": "The last failure event timestamp field as epoch at UTC in milliseconds."
    },
    {
      "Searchable": {
        "fieldName": "lastErroredAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastErroredAtMillis",
      "default": null,
      "doc": "The last error event timestamp field as epoch at UTC in milliseconds."
    },
    {
      "Searchable": {
        "fieldName": "lastPassedAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastPassedAtMillis",
      "default": null,
      "doc": "The last pass event timestamp field as epoch at UTC in milliseconds."
    },
    {
      "Searchable": {
        "fieldName": "lastInitializedAtMillis",
        "fieldType": "DATETIME"
      },
      "type": [
        "null",
        "long"
      ],
      "name": "lastInitializedAtMillis",
      "default": null,
      "doc": "The last initialized event timestamp field as epoch at UTC in milliseconds."
    },
    {
      "Searchable": {
        "addToFilters": true,
        "fieldName": "assertionStatus",
        "fieldType": "KEYWORD"
      },
      "type": [
        "null",
        {
          "type": "enum",
          "name": "AssertionStatus",
          "namespace": "com.linkedin.pegasus2avro.assertion",
          "symbols": [
            "PASSING",
            "FAILING",
            "ERROR",
            "INIT"
          ],
          "doc": "Latest assertion status derived from run results and monitor errors."
        }
      ],
      "name": "assertionStatus",
      "default": null,
      "doc": "The latest assertion status, incorporating run results and monitor errors."
    }
  ],
  "doc": "Derived.\nTracks the latest summary details of an assertion."
}