{
  "type": "record",
  "Aspect": {
    "name": "datasetKey",
    "keyForEntity": "dataset",
    "entityCategory": "core",
    "entityAspects": [
      "viewProperties",
      "subTypes",
      "datasetProfile",
      "datasetUsageStatistics",
      "operation",
      "domains",
      "applications",
      "schemaMetadata",
      "status",
      "container",
      "deprecation",
      "testResults",
      "siblings",
      "embed",
      "incidentsSummary",
      "datasetProperties",
      "editableDatasetProperties",
      "datasetDeprecation",
      "datasetUpstreamLineage",
      "upstreamLineage",
      "institutionalMemory",
      "ownership",
      "editableSchemaMetadata",
      "globalTags",
      "glossaryTerms",
      "browsePaths",
      "dataPlatformInstance",
      "browsePathsV2",
      "access",
      "structuredProperties",
      "forms",
      "partitionsSummary",
      "versionProperties",
      "icebergCatalogInfo",
      "logicalParent",
      "inferredNeighbors",
      "inferredMetadata",
      "schemaFieldsInferredMetadata",
      "schemaFieldsInferredNeighbors",
      "assertionsSummary",
      "usageFeatures",
      "storageFeatures",
      "lineageFeatures",
      "proposals",
      "schemaProposals",
      "anomaliesSummary",
      "share",
      "origin",
      "documentation",
      "entityInferenceMetadata",
      "assetSettings"
    ],
    "entityDoc": "Datasets represent logical or physical data assets stored or represented in various data platforms. Tables, Views, Streams are all instances of datasets."
  },
  "name": "DatasetKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "fields": [
    {
      "Searchable": {
        "enableAutocomplete": true,
        "fieldType": "URN"
      },
      "java": {
        "class": "com.linkedin.pegasus2avro.common.urn.Urn"
      },
      "type": "string",
      "name": "platform",
      "doc": "Data platform urn associated with the dataset",
      "Urn": "Urn"
    },
    {
      "Searchable": {
        "boostScore": 10.0,
        "enableAutocomplete": true,
        "fieldName": "id",
        "fieldType": "WORD_GRAM"
      },
      "type": "string",
      "name": "name",
      "doc": "Unique guid for dataset"
    },
    {
      "Searchable": {
        "addToFilters": true,
        "fieldType": "TEXT_PARTIAL",
        "filterNameOverride": "Environment",
        "queryByDefault": false,
        "searchLabel": "origin"
      },
      "type": {
        "type": "enum",
        "symbolDocs": {
          "CORP": "Designates corporation fabrics",
          "DEV": "Designates development fabrics",
          "EI": "Designates early-integration fabrics",
          "NON_PROD": "Designates non-production fabrics",
          "PRD": "Alternative Prod spelling",
          "PRE": "Designates pre-production fabrics",
          "PROD": "Designates production fabrics",
          "QA": "Designates quality assurance fabrics",
          "RVW": "Designates review fabrics",
          "SANDBOX": "Designates sandbox fabrics",
          "SBX": "Alternative spelling for sandbox",
          "SIT": "System Integration Testing",
          "STG": "Designates staging fabrics",
          "TEST": "Designates testing fabrics",
          "TST": "Alternative Test spelling",
          "UAT": "Designates user acceptance testing fabrics"
        },
        "name": "FabricType",
        "namespace": "com.linkedin.pegasus2avro.common",
        "symbols": [
          "DEV",
          "TEST",
          "QA",
          "UAT",
          "EI",
          "PRE",
          "STG",
          "NON_PROD",
          "PROD",
          "CORP",
          "RVW",
          "PRD",
          "TST",
          "SIT",
          "SBX",
          "SANDBOX"
        ],
        "doc": "Fabric group type"
      },
      "name": "origin",
      "doc": "Fabric type where dataset belongs to or where it was generated."
    }
  ],
  "doc": "Key for a Dataset"
}