EXCLUDED_PATTERNS = [
    "_ingestion",
    "amplitude",
    "analytics",
    "anomaly",
    "anomalo",
    "airflow",
    "app",
    "api",
    "aws",
    "braze",
    "bigquery",
    "backfill",
    "billing",
    "bot",
    "census",
    "customer_io",
    "connector",
    "composer",
    "compute",
    "circleci",
    "classifier",
    "cron",
    "datahub",
    "data-engine",
    "dbt",
    "datadog",
    "deploy",
    "databricks",
    "dataflow",
    "dataplex",
    "dagster",
    "enterprise",
    "export",
    "etl",
    "fivetran",
    "function",
    "google",
    "gcp",
    "gke",
    "grafana",
    "hex",
    "hightouch",
    "ingest",
    "infra",
    "infer",
    "integration",
    "iam",
    "job",
    "jenkins",
    "looker",
    "lineage",
    "monte_carlo",
    "netsuite",
    "process",
    "prefect",
    "pipeline",
    "query",
    "redash",
    "realtime",
    "report",
    "remote-executor",
    "runner",
    "sagemaker",
    "salesforce",
    "sigma",
    "sandbox",
    "snowplow",
    "segment",
    "sync",
    "schedul",
    "svc",
    "sa_",
    "_sa",
    "sa-",
    "-sa",
    "snowflake",
    "service",
    "system",
    "spark",
    "task",
    "test",
    "team",
    "talend",
    "teleskope",
    "train",
    "tableau",
    "unknown",
    "wiz",
    "warehouse",
    "workload",
    "workflow",
    "worker",
]
